API Star Authentication
=======================
|build-status| |coverage| |version|

:Version: 0.3.3
:Status: Production/Stable
:Author: Sander Mathijs van Veen

Authentication integration based on SQLAlchemy for API Star.


.. |build-status| image:: https://travis-ci.org/smvv/apistar-auth.svg?branch=master
    :alt: build status
    :scale: 100%
    :target: https://travis-ci.org/smvv/apistar-auth
.. |coverage| image:: https://codecov.io/gh/smvv/apistar-auth/branch/master/graph/badge.svg
    :alt: coverage
    :scale: 100%
    :target: https://codecov.io/gh/smvv/apistar-auth/branch/master/graph/badge.svg
.. |version| image:: https://badge.fury.io/py/apistar-auth.svg
    :alt: version
    :scale: 100%
    :target: https://badge.fury.io/py/apistar-auth
